package
Version:
v1.36.3
Opens a new window with list of versions in this module.
Published: Mar 2, 2026
License: MIT
Opens a new window with license information.
Imports: 0
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type SocialMedia struct {
Facebook string `json:"facebook,omitempty"`
Instagram string `json:"instagram,omitempty"`
Gplus string `json:"gplus,omitempty"`
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.